@@ -25,11 +25,10 @@
 #if HAVE_TUNEPIMP > 0
 
 #include <kprotocolmanager.h>
-#include <kurl.h>
-#include <kdebug.h>
 #include <kio/job.h>
 
 #include <QCoreApplication>
+#include <QUrl>
 #include <QtAlgorithms>
 #include <QMutex>
 #include <QRegExp>
@@ -46,7 +45,7 @@
 #include <fixx11h.h>
 #endif
 
-#include "ktrm.moc"
+#include "juk_debug.h"
 
 class KTRMLookup;
 
@@ -165,7 +164,7 @@ protected:
             // Check what hosts are allowed to proceed without being proxied,
             // or if using reversed proxy, what hosts must be proxied.
             foreach(const QString &host, noProxies) {
-                const QString normalizedHost(KUrl::fromAce(KUrl::toAce(host)));
+                const QString normalizedHost(QUrl().setHost(host).host(QUrl::EncodeUnicode));
 
                 if(normalizedHost == tunepimpHost ||
                    tunepimpHost.endsWith('.' + normalizedHost))
@@ -189,11 +188,11 @@ protected:
                 useProxy = !useProxy;
 
             if(useProxy) {
-                KUrl proxy = KProtocolManager::proxyFor("http");
+                QUrl proxy = QUrl::fromUserInput(KProtocolManager::proxyFor("http"));
                 QString proxyHost = proxy.host();
 
-                kDebug() << "Using proxy server " << proxyHost << " for www.musicbrainz.org.\n";
-                tp_SetProxy(m_pimp, proxyHost.toAscii(), short(proxy.port()));
+                qCDebug(JUK_LOG) << "Using proxy server " << proxyHost << " for www.musicbrainz.org.\n";
+                tp_SetProxy(m_pimp, proxyHost.toUtf8(), short(proxy.port()));
             }
         }
 #else
@@ -490,7 +489,7 @@ int KTRMLookup::fileId() const
 
 void KTRMLookup::recognized()
 {
-    kDebug() << d->file;
+    qCDebug(JUK_LOG) << d->file;
 
     d->results.clear();
 
@@ -516,7 +515,7 @@ void KTRMLookup::recognized()
 
 void KTRMLookup::unrecognized()
 {
-    kDebug() << d->file;
+    qCDebug(JUK_LOG) << d->file;
 #if HAVE_TUNEPIMP >= 4
     char trm[255];
     bool finish = false;
@@ -547,12 +546,12 @@ void KTRMLookup::unrecognized()
 void KTRMLookup::collision()
 {
 #if HAVE_TUNEPIMP < 5
-    kDebug() << d->file;
+    qCDebug(JUK_LOG) << d->file;
 
     track_t track = tp_GetTrack(KTRMRequestHandler::instance()->tunePimp(), d->fileId);
 
     if(track <= 0) {
-        kDebug() << "invalid track number";
+        qCDebug(JUK_LOG) << "invalid track number";
         return;
     }
 
@@ -566,17 +565,17 @@ void KTRMLookup::collision()
 
         switch(type) {
         case eNone:
-            kDebug() << "eNone";
+            qCDebug(JUK_LOG) << "eNone";
             break;
         case eArtistList:
-            kDebug() << "eArtistList";
+            qCDebug(JUK_LOG) << "eArtistList";
             break;
         case eAlbumList:
-            kDebug() << "eAlbumList";
+            qCDebug(JUK_LOG) << "eAlbumList";
             break;
         case eTrackList:
         {
-            kDebug() << "eTrackList";
+            qCDebug(JUK_LOG) << "eTrackList";
             albumtrackresult_t **tracks = (albumtrackresult_t **) results;
             d->results.clear();
 
@@ -601,7 +600,7 @@ void KTRMLookup::collision()
             break;
         }
         case eMatchedTrack:
-            kDebug() << "eMatchedTrack";
+            qCDebug(JUK_LOG) << "eMatchedTrack";
             break;
         }
 
@@ -696,7 +695,7 @@ void KTRMLookup::lookupResult( KJob* job )
 
 void KTRMLookup::error()
 {
-    kDebug() << d->file;
+    qCDebug(JUK_LOG) << d->file;
 
     d->results.clear();
     finished();
