@@ -20,16 +20,16 @@
 // Watched implementation
 ////////////////////////////////////////////////////////////////////////////////
 
-void Watched::currentChanged()
+void Watched::currentPlayingItemChanged()
 {
     foreach(PlaylistObserver *observer, m_observers)
-        observer->updateCurrent();
+        observer->playingItemHasChanged();
 }
 
-void Watched::dataChanged()
+void Watched::playlistItemsChanged()
 {
     foreach(PlaylistObserver *observer, m_observers)
-        observer->updateData();
+        observer->playlistItemDataHasChanged();
 }
 
 void Watched::addObserver(PlaylistObserver *observer)
