@@ -17,12 +17,11 @@
 #include "searchplaylist.h"
 #include "juk-exception.h"
 
-#include <kdebug.h>
-
 #include <QHash>
 
 #include "playlistitem.h"
 #include "collectionlist.h"
+#include "juk_debug.h"
 
 ////////////////////////////////////////////////////////////////////////////////
 // public methods
@@ -77,7 +76,7 @@ void SearchPlaylist::updateItems()
     createItems(newItems);
 
     if(synchronizePlaying()) {
-        kDebug() << "synchronizing playing";
+        qCDebug(JUK_LOG) << "synchronizing playing";
         synchronizePlayingItems(m_search.playlists(), true);
     }
 }
@@ -112,6 +111,4 @@ QDataStream &operator>>(QDataStream &s, SearchPlaylist &p)
     return s;
 }
 
-#include "searchplaylist.moc"
-
 // vim: set et sw=4 tw=0 sta:
