@@ -20,23 +20,21 @@
 #include "tag.h"
 #include "actioncollection.h"
 #include "tagtransactionmanager.h"
+#include "juk_debug.h"
 
 #include <kactioncollection.h>
-#include <kconfiggroup.h>
 #include <kcombobox.h>
 #include <klineedit.h>
-#include <knuminput.h>
 #include <ktextedit.h>
-#include <kapplication.h>
 #include <kmessagebox.h>
-#include <kconfig.h>
-#include <klocale.h>
-#include <kdebug.h>
+#include <KSharedConfig>
+#include <KConfigGroup>
 #include <kiconloader.h>
-#include <kicon.h>
 #include <ktoggleaction.h>
-#include <kshortcut.h>
+#include <KLocalizedString>
 
+#include <QAction>
+#include <QIcon>
 #include <QLabel>
 #include <QApplication>
 #include <QCheckBox>
@@ -116,14 +114,12 @@ public:
     {
     }
 
-    virtual void updateData()
+    virtual void playlistItemDataHasChanged() Q_DECL_FINAL
     {
         if(m_parent && m_parent->m_currentPlaylist && m_parent->isVisible())
             m_parent->slotSetItems(m_parent->m_currentPlaylist->selectedItems());
     }
 
-    virtual void updateCurrent() {}
-
 private:
     TagEditor *m_parent;
 };
@@ -261,7 +257,6 @@ void TagEditor::slotRefresh()
 
     // If there is more than one item in the m_items that we're dealing with...
 
-
     QList<QWidget *> disabledForMulti;
 
     disabledForMulti << fileNameLabel << fileNameBox << lengthLabel << lengthBox
@@ -435,7 +430,7 @@ void TagEditor::readConfig()
 {
     // combo box completion modes
 
-    KConfigGroup config(KGlobal::config(), "TagEditor");
+    KConfigGroup config(KSharedConfig::openConfig(), "TagEditor");
     if(artistNameBox && albumNameBox) {
         readCompletionMode(config, artistNameBox, "ArtistNameBoxMode");
         readCompletionMode(config, albumNameBox, "AlbumNameBoxMode");
@@ -460,8 +455,8 @@ void TagEditor::readConfig()
 
 void TagEditor::readCompletionMode(const KConfigGroup &config, KComboBox *box, const QString &key)
 {
-    KGlobalSettings::Completion mode =
-        KGlobalSettings::Completion(config.readEntry(key, (int)KGlobalSettings::CompletionAuto));
+    KCompletion::CompletionMode mode =
+        KCompletion::CompletionMode(config.readEntry(key, (int)KCompletion::CompletionAuto));
 
     box->setCompletionMode(mode);
 }
@@ -470,7 +465,7 @@ void TagEditor::saveConfig()
 {
     // combo box completion modes
 
-    KConfigGroup config(KGlobal::config(), "TagEditor");
+    KConfigGroup config(KSharedConfig::openConfig(), "TagEditor");
 
     if(artistNameBox && albumNameBox) {
         config.writeEntry("ArtistNameBoxMode", (int)artistNameBox->completionMode());
@@ -482,46 +477,44 @@ void TagEditor::saveConfig()
 
 void TagEditor::setupActions()
 {
-    KToggleAction *show = new KToggleAction(KIcon(QLatin1String("document-properties")),
+    KToggleAction *show = new KToggleAction(QIcon::fromTheme(QLatin1String("document-properties")),
                                             i18n("Show &Tag Editor"), this);
     ActionCollection::actions()->addAction("showEditor", show);
-    connect(show, SIGNAL(toggled(bool)), this, SLOT(setShown(bool)));
+    connect(show, &QAction::toggled, this, &TagEditor::setVisible);
 
-    KAction *act = new KAction(KIcon(QLatin1String( "document-save")), i18n("&Save"), this);
+    QAction *act = new QAction(QIcon::fromTheme(QLatin1String( "document-save")), i18n("&Save"), this);
     ActionCollection::actions()->addAction("saveItem", act);
-    act->setShortcut(Qt::CTRL + Qt::Key_T);
-    connect(act, SIGNAL(triggered(bool)), SLOT(slotSave()));
+    ActionCollection::actions()->setDefaultShortcut(act,
+            QKeySequence(Qt::CTRL + Qt::Key_T));
+    connect(act, &QAction::triggered, this, &TagEditor::slotSave);
 }
 
 void TagEditor::setupLayout()
 {
     setupUi(this);
 
-    foreach(QWidget *input, findChildren<QWidget *>()) {
-        if(input->inherits("QLineEdit") || input->inherits("QComboBox"))
-            connect(input, SIGNAL(textChanged(QString)), this, SLOT(slotDataChanged()));
-        if(input->inherits("QComboxBox"))
-            connect(input, SIGNAL(activated(int)), this, SLOT(slotDataChanged()));
-        if(input->inherits("QSpinBox"))
-            connect(input, SIGNAL(valueChanged(int)), this, SLOT(slotDataChanged()));
-        if(input->inherits("QTextEdit"))
-            connect(input, SIGNAL(textChanged()), this, SLOT(slotDataChanged()));
-    }
-
     // Do some meta-programming to find the matching enable boxes
 
-    foreach(QCheckBox *enable, findChildren<QCheckBox *>(QRegExp("Enable"))) {
-        enable->hide();
-        QRegExp re('^' + enable->objectName().replace("Enable", "") + "(Box|Spin)$");
-        QList<QWidget *> targets = findChildren<QWidget *>(re);
-        Q_ASSERT(!targets.isEmpty());
-        m_enableBoxes[targets.front()] = enable;
+    for(auto enable : findChildren<QCheckBox *>(QRegExp("Enable$"))) {
+        enable->hide(); // These are shown only when multiple items are being edited
+
+        // Each enable checkbox is identified by having its objectName end in "Enable".
+        // The corresponding widget to be adjusted is identified by assigning a custom
+        // property in Qt Designer "associatedObjectName", the value of which is the name
+        // for the widget to be enabled (or not).
+        auto associatedVariantValue = enable->property("associatedObjectName");
+        Q_ASSERT(associatedVariantValue.isValid());
+
+        QWidget *associatedWidget = findChild<QWidget *>(associatedVariantValue.toString());
+        Q_ASSERT(associatedWidget != nullptr);
+
+        m_enableBoxes[associatedWidget] = enable;
     }
 
-    // Make sure that the labels are as tall as the enable buttons so that the
-    // layout doesn't jump around.
+    // Make sure that the labels are as tall as the enable boxes so that the
+    // layout doesn't jump around as the enable boxes are shown/hidden.
 
-    foreach(QLabel *label, findChildren<QLabel *>()) {
+    for(auto label : findChildren<QLabel *>()) {
         if(m_enableBoxes.contains(label->buddy()))
             label->setMinimumHeight(m_enableBoxes[label->buddy()]->height());
     }
@@ -533,7 +526,7 @@ void TagEditor::save(const PlaylistItemList &list)
 {
     if(!list.isEmpty() && m_dataChanged) {
 
-        KApplication::setOverrideCursor(Qt::WaitCursor);
+        QApplication::setOverrideCursor(Qt::WaitCursor);
         m_dataChanged = false;
         m_performingSave = true;
 
@@ -549,7 +542,7 @@ void TagEditor::save(const PlaylistItemList &list)
             // playlists will try to modify the file we edit if the tag changes
             // due to our alterations here.
 
-            qApp->processEvents(QEventLoop::ExcludeUserInput);
+            qApp->processEvents(QEventLoop::ExcludeUserInputEvents);
 
             PlaylistItem *item = *it;
 
@@ -598,9 +591,9 @@ void TagEditor::save(const PlaylistItemList &list)
         }
 
         TagTransactionManager::instance()->commit();
-        CollectionList::instance()->dataChanged();
+        CollectionList::instance()->playlistItemsChanged();
         m_performingSave = false;
-        KApplication::restoreOverrideCursor();
+        QApplication::restoreOverrideCursor();
     }
 }
 
@@ -635,22 +628,13 @@ void TagEditor::showEvent(QShowEvent *e)
     QWidget::showEvent(e);
 }
 
-bool TagEditor::eventFilter(QObject *watched, QEvent *e)
-{
-    QKeyEvent *ke = static_cast<QKeyEvent*>(e);
-    if(watched->inherits("QSpinBox") && e->type() == QEvent::KeyRelease && ke->modifiers() == 0)
-        slotDataChanged();
-
-    return false;
-}
-
 ////////////////////////////////////////////////////////////////////////////////
 // private slots
 ////////////////////////////////////////////////////////////////////////////////
 
-void TagEditor::slotDataChanged(bool c)
+void TagEditor::slotDataChanged()
 {
-    m_dataChanged = c;
+    m_dataChanged = true;
 }
 
 void TagEditor::slotItemRemoved(PlaylistItem *item)
@@ -668,6 +652,4 @@ void TagEditor::slotPlaylistDestroyed(Playlist *p)
     }
 }
 
-#include "tageditor.moc"
-
 // vim: set et sw=4 tw=0 sta:
