@@ -16,64 +16,40 @@
 
 #include "tagtransactionmanager.h"
 
-#include <kdebug.h>
-#include <klocale.h>
-#include <kmessagebox.h>
-#include <kaction.h>
-#include <kapplication.h>
+#include <KMessageBox>
+#include <KLocalizedString>
 
+#include <QAction>
+#include <QApplication>
 #include <QFileInfo>
 #include <QDir>
+#include <QGlobalStatic>
 
 #include "playlistitem.h"
 #include "collectionlist.h"
 #include "tag.h"
 #include "actioncollection.h"
+#include "juk_debug.h"
 
 using ActionCollection::action;
 
-TagTransactionManager *TagTransactionManager::m_manager = 0;
-
-TagTransactionAtom::TagTransactionAtom() : m_item(0), m_tag(0)
-{
-    action("edit_undo")->setEnabled(false);
-}
-
-TagTransactionAtom::TagTransactionAtom(const TagTransactionAtom &other) :
-    m_item(other.m_item), m_tag(other.m_tag)
-{
-    other.m_tag = 0; // Only allow one owner
-}
-
-TagTransactionAtom::TagTransactionAtom(PlaylistItem *item, Tag *tag) :
-    m_item(item), m_tag(tag)
-{
-}
-
-TagTransactionAtom::~TagTransactionAtom()
-{
-    delete m_tag;
-}
-
-TagTransactionAtom &TagTransactionAtom::operator=(const TagTransactionAtom &other)
-{
-    m_item = other.m_item;
-    m_tag = other.m_tag;
-
-    other.m_tag = 0; // Only allow one owner
-
-    return *this;
-}
+Q_GLOBAL_STATIC(TagTransactionManager, g_tagManager)
 
 TagTransactionManager *TagTransactionManager::instance()
 {
-    return m_manager;
+    return g_tagManager;
+}
+
+TagTransactionAtom::TagTransactionAtom(PlaylistItem *item, Tag *tag)
+    : m_item(item)
+    , m_tag(tag)
+{
 }
 
 void TagTransactionManager::changeTagOnItem(PlaylistItem *item, Tag *newTag)
 {
     if(!item) {
-        kWarning() << "Trying to change tag on null PlaylistItem.\n";
+        qCWarning(JUK_LOG) << "Trying to change tag on null PlaylistItem.\n";
         return;
     }
 
@@ -82,7 +58,7 @@ void TagTransactionManager::changeTagOnItem(PlaylistItem *item, Tag *newTag)
     // signals from CollectionList to ensure that the commit list and the
     // playlists stay in sync.
 
-    m_list.append(TagTransactionAtom(item->collectionItem(), newTag));
+    m_list.emplace_back(item->collectionItem(), newTag);
 }
 
 Tag *TagTransactionManager::duplicateTag(const Tag *tag, const QString &fileName)
@@ -112,7 +88,7 @@ void TagTransactionManager::forget()
 
 bool TagTransactionManager::undo()
 {
-    kDebug() << "Undoing " << m_undoList.count() << " changes.\n";
+    qCDebug(JUK_LOG) << "Undoing " << m_undoList.size() << " changes.\n";
 
     forget();  // Scrap our old changes (although the list should be empty
                // anyways.
@@ -125,12 +101,6 @@ bool TagTransactionManager::undo()
     return result;
 }
 
-TagTransactionManager::TagTransactionManager(QWidget *parent) : QObject(parent)
-{
-    setObjectName( QLatin1String("tagmanager" ));
-    m_manager = this;
-}
-
 bool TagTransactionManager::renameFile(const QFileInfo &from, const QFileInfo &to) const
 {
    if(!QFileInfo(to.path()).isWritable() || !from.exists())
@@ -142,7 +112,7 @@ bool TagTransactionManager::renameFile(const QFileInfo &from, const QFileInfo &t
            i18n("This file already exists.\nDo you want to replace it?"),
            i18n("File Exists"),KGuiItem(i18n("Replace"))) == KMessageBox::Continue)
    {
-       kDebug() << "Renaming " << from.absoluteFilePath() << " to " << to.absoluteFilePath();
+       qCDebug(JUK_LOG) << "Renaming " << from.absoluteFilePath() << " to " << to.absoluteFilePath();
        QDir currentDir;
        return currentDir.rename(from.absoluteFilePath(), to.absoluteFilePath());
    }
@@ -152,17 +122,17 @@ bool TagTransactionManager::renameFile(const QFileInfo &from, const QFileInfo &t
 
 bool TagTransactionManager::processChangeList(bool undo)
 {
-    TagAlterationList::ConstIterator it, end;
+    TagAlterationList::const_iterator it, end;
     QStringList errorItems;
 
-    it = undo ? m_undoList.constBegin() : m_list.constBegin();
-    end = undo ? m_undoList.constEnd() : m_list.constEnd();
+    it = undo ? m_undoList.cbegin() : m_list.cbegin();
+    end = undo ? m_undoList.cend() : m_list.cend();
 
     emit signalAboutToModifyTags();
 
     for(; it != end; ++it) {
         PlaylistItem *item = (*it).item();
-        Tag *tag = (*it).tag();
+        const Tag *tag = (*it).tag();
 
         QFileInfo newFile(tag->fileName());
 
@@ -175,12 +145,13 @@ bool TagTransactionManager::processChangeList(bool undo)
 
         if(tag->save()) {
             if(!undo)
-                m_undoList.append(TagTransactionAtom(item, duplicateTag(item->file().tag())));
+                m_undoList.emplace_back(item, duplicateTag(item->file().tag()));
 
             item->file().setFile(tag->fileName());
             item->refreshFromDisk();
-            item->repaint();
-            item->playlist()->dataChanged();
+            //FIXME repaint
+            //item->repaint();
+            item->playlist()->playlistItemsChanged();
             item->playlist()->update();
         }
         else {
@@ -193,11 +164,11 @@ bool TagTransactionManager::processChangeList(bool undo)
             errorItems.append(str);
         }
 
-        kapp->processEvents();
+        qApp->processEvents();
     }
 
     undo ? m_undoList.clear() : m_list.clear();
-    if(!undo && !m_undoList.isEmpty())
+    if(!undo && !m_undoList.empty())
         action("edit_undo")->setEnabled(true);
     else
         action("edit_undo")->setEnabled(false);
@@ -212,6 +183,4 @@ bool TagTransactionManager::processChangeList(bool undo)
     return errorItems.isEmpty();
 }
 
-#include "tagtransactionmanager.moc"
-
 // vim: set et sw=4 tw=0 sta:
